wsireg.reg\_transforms package
==============================

Submodules
----------

wsireg.reg\_transforms.reg\_transform module
--------------------------------------------

.. automodule:: wsireg.reg_transforms.reg_transform
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.reg\_transforms.reg\_transform\_seq module
-------------------------------------------------

.. automodule:: wsireg.reg_transforms.reg_transform_seq
   :members:
   :undoc-members:
   :show-inheritance:

